@@ -34,6 +34,9 @@
 #'   variable (on the rhs of formula) for fitting to the attempted.
 #' @param formula a "formula" object. Using aesthetic names instead of
 #'   original variable names.
+#' @param fit.seed RNG seed argument passed to \code{\link[base:Random]{set.seed}()}.
+#'   Defaults to \code{NA}, which means that \code{set.seed()} will not be
+#'   called.
 #' @param orientation character Either "x" or "y" controlling the default for
 #'   \code{formula}.
 #'
@@ -186,6 +189,7 @@ stat_fit_deviations <- function(mapping = NULL,
                                 method.args = list(),
                                 n.min = 2L,
                                 formula = NULL,
+                                fit.seed = NA,
                                 na.rm = FALSE,
                                 orientation = NA,
                                 show.legend = FALSE,
@@ -203,6 +207,13 @@ stat_fit_deviations <- function(mapping = NULL,
     method.name <- "missing"
   }
 
+  temp <- guess_orientation(orientation = orientation,
+                            formula = formula,
+                            default.formula = y ~ x,
+                            formula.on.x = FALSE)
+  orientation <- temp[["orientation"]]
+  formula <-  temp[["formula"]]
+
   ggplot2::layer(
     stat = StatFitDeviations, data = data, mapping = mapping, geom = geom,
     position = position, show.legend = show.legend, inherit.aes = inherit.aes,
@@ -212,6 +223,7 @@ stat_fit_deviations <- function(mapping = NULL,
                    method.args = method.args,
                    n.min = n.min,
                    formula = formula,
+                   fit.seed = fit.seed,
                    na.rm = na.rm,
                    orientation = orientation,
                    ...)
@@ -232,34 +244,17 @@ deviations_compute_group_fun <- function(data,
                                          method.args = list(),
                                          n.min = 2L,
                                          formula = y ~ x,
+                                         fit.seed = NA,
                                          orientation = "x") {
 
   stopifnot(!any(c("formula", "data") %in% names(method.args)))
+
   if (is.null(data$weight)) {
     data$weight <- 1
   }
 
-  # we guess formula from orientation
-  if (is.null(formula)) {
-    if (is.na(orientation) || orientation == "x") {
-      formula = y ~ x
-    } else if (orientation == "y") {
-      formula = x ~ y
-    }
-  }
-  # we guess orientation from formula
-  if (is.na(orientation)) {
-    orientation <- unname(c(x = "y", y = "x")[as.character(formula)[2]])
-  }
-
-  if (orientation == "x") {
-    if (length(unique(data$x)) < n.min) {
+  if (length(unique(data[[orientation]])) < n.min) {
       return(data.frame())
-    }
-  } else if (orientation == "y") {
-    if (length(unique(data$y)) < n.min) {
-      return(data.frame())
-    }
   }
 
   # If method was specified as a character string, replace with
@@ -314,6 +309,9 @@ deviations_compute_group_fun <- function(data,
     names(fun.args)[1] <- "model"
   }
 
+  if (!is.na(fit.seed)) {
+    set.seed(fit.seed)
+  }
   # quantreg contains code with partial matching of names!
   # so we silence selectively only these warnings
   withCallingHandlers({
@@ -325,10 +323,22 @@ deviations_compute_group_fun <- function(data,
     }
   })
 
+  if (!length(fm) || (is.atomic(fm) && is.na(fm))) {
+    return(data.frame())
+  } else if (!(inherits(fm, "lm") || inherits(fm, "lmrob") ||
+               inherits(fm, "gls") || inherits(fm, "lqs") ||
+               inherits(fm, "lts") || inherits(fm, "sma"))) {
+    message("Method \"", method.name,
+            "\" did not return a ",
+            "\"lm\", \"lmrob\", \"lqs\", \"lts\", \"gls\" or \"sma\" ",
+            "object, possible failure ahead.")
+  }
+
   # As users may use model fit functions that we have not tested
   # we try hard to extract the components from the model fit object
   try(fitted.vals <- stats::fitted(fm))
-  if (inherits(fitted.vals, "try-error")) {
+  if (inherits(fitted.vals, "try-error") ||
+      length(fitted.vals) != nrow(data)) {
     if (exists("fitted.values", fm) &&  # defensive
         length(fm[["fitted.values"]]) == nrow(data)) {
       fitted.vals <- fm[["fitted.values"]]
@@ -355,8 +365,9 @@ deviations_compute_group_fun <- function(data,
     weight.vals <- rep_len(1, nrow(data))
   } else {
     rob.weight.vals <- rep(NA_real_, nrow(data))
-    try(prior.weight.vals <- stats::weights(fm))
-    if (inherits(weight.vals, "try-error")) {
+    try(weight.vals <- stats::weights(fm))
+    if (inherits(weight.vals, "try-error") ||
+        length(weight.vals) != nrow(data)) {
       if (exists("weights", fm) &&  # defensive
           length(fm[["weights"]]) == nrow(data)) {
         weight.vals <- fm[["weights"]]
@@ -408,6 +419,7 @@ stat_fit_fitted <- function(mapping = NULL, data = NULL, geom = "point",
                             method.args = list(),
                             n.min = 2L,
                             formula = NULL,
+                            fit.seed = NA,
                             position = "identity",
                             na.rm = FALSE,
                             orientation = NA,
@@ -426,6 +438,13 @@ stat_fit_fitted <- function(mapping = NULL, data = NULL, geom = "point",
     method.name <- "missing"
   }
 
+  temp <- guess_orientation(orientation = orientation,
+                            formula = formula,
+                            default.formula = y ~ x,
+                            formula.on.x = FALSE)
+  orientation <- temp[["orientation"]]
+  formula <-  temp[["formula"]]
+
   ggplot2::layer(
     stat = StatFitFitted, data = data, mapping = mapping, geom = geom,
     position = position, show.legend = show.legend, inherit.aes = inherit.aes,
@@ -435,6 +454,7 @@ stat_fit_fitted <- function(mapping = NULL, data = NULL, geom = "point",
                    method.args = method.args,
                    n.min = n.min,
                    formula = formula,
+                   fit.seed = fit.seed,
                    na.rm = na.rm,
                    orientation = orientation,
                    ...)
@@ -453,36 +473,19 @@ fitted_compute_group_fun <- function(data,
                                      method,
                                      method.name,
                                      method.args,
-                                     n.min,
-                                     formula,
-                                     orientation,
+                                     n.min = 2L,
+                                     formula =  y ~ x,
+                                     fit.seed = NA,
+                                     orientation = "x",
                                      return.fitted = FALSE) {
   stopifnot(!any(c("formula", "data") %in% names(method.args)))
+
   if (is.null(data$weight)) {
     data$weight <- 1
   }
 
-  # we guess formula from orientation
-  if (is.null(formula)) {
-    if (is.na(orientation) || orientation == "x") {
-      formula = y ~ x
-    } else if (orientation == "y") {
-      formula = x ~ y
-    }
-  }
-  # we guess orientation from formula
-  if (is.na(orientation)) {
-    orientation <- unname(c(x = "y", y = "x")[as.character(formula)[2]])
-  }
-
-  if (orientation == "x") {
-    if (length(unique(data$x)) < n.min) {
-      return(data.frame())
-    }
-  } else if (orientation == "y") {
-    if (length(unique(data$y)) < n.min) {
-      return(data.frame())
-    }
+  if (length(unique(data[[orientation]])) < n.min) {
+    return(data.frame())
   }
 
   # If method was specified as a character string, replace with
@@ -540,6 +543,9 @@ fitted_compute_group_fun <- function(data,
     names(fun.args)[1] <- "model"
   }
 
+  if (!is.na(fit.seed)) {
+    set.seed(fit.seed)
+  }
   # quantreg contains code with partial matching of names!
   # so we silence selectively only these warnings
   withCallingHandlers({
@@ -551,10 +557,22 @@ fitted_compute_group_fun <- function(data,
     }
   })
 
+  if (!length(fm) || (is.atomic(fm) && is.na(fm))) {
+    return(data.frame())
+  } else if (!(inherits(fm, "lm") || inherits(fm, "lmrob") ||
+               inherits(fm, "gls") || inherits(fm, "lqs") ||
+               inherits(fm, "lts") || inherits(fm, "sma"))) {
+    message("Method \"", method.name,
+            "\" did not return a ",
+            "\"lm\", \"lmrob\", \"lqs\", \"lts\", \"gls\" or \"sma\" ",
+            "object, possible failure ahead.")
+  }
+
   # As users may use model fit functions that we have not tested
   # we try hard to extract the components from the model fit object
   try(fitted.vals <- stats::fitted(fm))
-  if (inherits(fitted.vals, "try-error")) {
+  if (inherits(fitted.vals, "try-error") ||
+      length(fitted.vals) != nrow(data)) {
     if (exists("fitted.values", fm) &&  # defensive
         length(fm[["fitted.values"]]) == nrow(data)) {
       fitted.vals <- fm[["fitted.values"]]
